@@ -41,7 +41,7 @@ func newClient(ctx *cli.Context, acc registration.User, keyType certcrypto.KeyTy
 		KeyType: keyType,
 		Timeout: time.Duration(ctx.Int("cert.timeout")) * time.Second,
 	}
-	config.UserAgent = fmt.Sprintf("lego-cli/%s", ctx.App.Version)
+	config.UserAgent = getUserAgent(ctx)
 
 	if ctx.IsSet("http-timeout") {
 		config.HTTPClient.Timeout = time.Duration(ctx.Int("http-timeout")) * time.Second
@@ -65,6 +65,8 @@ func getKeyType(ctx *cli.Context) certcrypto.KeyType {
 	switch strings.ToUpper(keyType) {
 	case "RSA2048":
 		return certcrypto.RSA2048
+	case "RSA3072":
+		return certcrypto.RSA3072
 	case "RSA4096":
 		return certcrypto.RSA4096
 	case "RSA8192":
@@ -87,6 +89,10 @@ func getEmail(ctx *cli.Context) string {
 	return email
 }
 
+func getUserAgent(ctx *cli.Context) string {
+	return strings.TrimSpace(fmt.Sprintf("%s lego-cli/%s", ctx.String("user-agent"), ctx.App.Version))
+}
+
 func createNonExistingFolder(path string) error {
 	if _, err := os.Stat(path); os.IsNotExist(err) {
 		return os.MkdirAll(path, 0o700)
